@@ -4,7 +4,7 @@
  * various preferences storage mediums.  It also includes all of the
  * functions for retrieving, storing, and checking preference values.
  *
- * Copyright 1999-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 1999-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -34,7 +34,6 @@ class Horde_Prefs implements ArrayAccess
     protected $_opts = array(
         'cache' => null,
         'logger' => null,
-        'password' => '',
         'sizecallback' => null,
         'storage' => null,
         'user' => ''
@@ -77,8 +76,6 @@ class Horde_Prefs implements ArrayAccess
      *         DEFAULT: No caching.
      * logger - (Horde_Log_Logger) Logging object.
      *          DEFAULT: NONE
-     * password - (string) The password associated with 'user'.
-     *            DEFAULT: NONE
      * sizecallback - (callback) If set, called when setting a value in the
      *                backend.
      *                DEFAULT: NONE
@@ -330,7 +327,7 @@ class Horde_Prefs implements ArrayAccess
     {
         return ($scope = $this->_getScope($pref))
             ? $this->_scopes[$scope]->isDefault($pref)
-            : false;
+            : true;
     }
 
     /**
