@@ -2,7 +2,7 @@
 /**
  * Storage driver for the preferences system.
  *
- * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -31,7 +31,7 @@ abstract class Horde_Prefs_Storage_Base
     public function __construct($user, array $params = array())
     {
         $this->_params = array_merge($this->_params, $params);
-        $this->_params['user'] = $user;
+        $this->_params['user'] = (string)$user;
     }
 
     /**
